from django.forms import CharField, CheckboxSelectMultiple, MultipleChoiceField
from django.utils.translation import gettext_lazy
from i18nfield.forms import I18nFormField, I18nTextInput
from pretix.base.forms import SettingsForm


class KeycloakCreatorForm(SettingsForm):
    keycloak_create_user_items = MultipleChoiceField(
        widget=CheckboxSelectMultiple(attrs={"class": "scrolling-multiple-choice"}),
        label=gettext_lazy("Ask Username for"),
        required=True,
        choices=[],
        help_text=gettext_lazy("These products will ask for a username."),
    )
    keycloak_create_user_authorization_token = CharField(
        label=gettext_lazy("Access token"),
        strip=True,
        help_text=gettext_lazy("Access token for the keycloak server. "),
    )
    keycloak_create_user_realm_url = CharField(
        label=gettext_lazy("Keycloak realm url"),
        strip=True,
        help_text=gettext_lazy("The url to keycloak including realm."),
    )
    keycloak_create_user_hint = I18nFormField(
        widget=I18nTextInput,
        label=gettext_lazy("Username field help text"),
        required=True,
        help_text=gettext_lazy("Explains what to enter"),
    )

    def __init__(self, *args, **kwargs):
        super().__init__(*args, **kwargs)
        self.fields["keycloak_create_user_items"].choices = [
            (i.pk, i.name) for i in self.obj.items.all()
        ]
